==> qtjambi-charts-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiCharts/QXYSeries_shell.h <==
#ifndef QXYSERIES_SHELL_H
#define QXYSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qxyseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qchart.h>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qimage.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QXYSeries_shell : public QXYSeries, public QtJambiShellInterface
{
public:
    ~QXYSeries_shell() override;

    void childEvent(QChildEvent* event0) override;
    QColor color() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setBrush(const QBrush& brush0) override;
    void setColor(const QColor& color0) override;
    void setPen(const QPen& pen0) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYSeries_access : public QXYSeries
{
    jobject __qt_color(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setBrush_cref_QBrush(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID brush0);
    void __qt_setColor_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID color0);
    void __qt_setPen_cref_QPen(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pen0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QXYSERIES_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCharts/QXYSeries_shell.h <==
#ifndef QXYSERIES_SHELL_H
#define QXYSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qxyseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qchart.h>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qimage.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QXYSeries_shell : public QXYSeries, public QtJambiShellInterface
{
public:
    ~QXYSeries_shell() override;

    void childEvent(QChildEvent* event0) override;
    QColor color() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setBrush(const QBrush& brush0) override;
    void setColor(const QColor& color0) override;
    void setPen(const QPen& pen0) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QXYSeries_access : public QXYSeries
{
    jobject __qt_color_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setBrush_cref_QBrush(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID brush0);
    void __qt_setColor_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID color0);
    void __qt_setPen_cref_QPen(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pen0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QXYSERIES_SHELL_H
